@@ -67,7 +67,7 @@ KompareListViewFrame::KompareListViewFrame(bool isSource,
     bottomLine->setFixedHeight(1);
     m_label.setMargin(3);
     m_layout.setSpacing(0);
-    m_layout.setMargin(0);
+    m_layout.setContentsMargins(0, 0, 0, 0);
     m_layout.addWidget(&m_label);
     m_layout.addWidget(bottomLine);
     m_layout.addWidget(&m_view);
